@@ -87,15 +87,16 @@ And it should do the rest.
 use 5.006;
 use strict;
 use Carp                  ();
-use Process               ();
-use File::Spec            ();
+use URI              1.57 ();
+use Process          0.29 ();
+use File::Temp       0.22 ();
+use File::Spec       0.80 ();
 use File::Spec::Unix      ();
-use File::Which           ();
-use File::Remove          ();
-use Config::Tiny          ();
-use Params::Util          '_INSTANCE';
-use LWP::UserAgent        ();
-use HTTP::Request::Common 'GET', 'PUT';
+use File::Which      0.05 ();
+use File::Remove     1.51 ();
+use Config::Tiny     2.00 ();
+use Params::Util     1.00 ();
+use HTTP::Tiny      0.014 ();
 use PITA::Image::Platform ();
 use PITA::Image::Task     ();
 use PITA::Image::Discover ();
@@ -103,7 +104,7 @@ use PITA::Image::Test     ();
 
 use vars qw{$VERSION @ISA $NOSERVER};
 BEGIN {
-	$VERSION = '0.43';
+	$VERSION = '0.60';
 	@ISA     = 'Process';
 }
 
@@ -209,7 +210,7 @@ sub cleanup {
 }
 
 sub injector {
-	$_[0]->{injector};	
+	$_[0]->{injector};
 }
 
 sub workarea {
@@ -248,7 +249,7 @@ sub add_platform {
 
 sub add_task {
 	my $self = shift;
-	my $task = _INSTANCE($_[0], 'PITA::Image::Task')
+	my $task = Params::Util::_INSTANCE($_[0], 'PITA::Image::Task')
 		or die("Passed bad param to add_task");
 	push @{$self->{tasks}}, $task;
 	1;
@@ -277,7 +278,7 @@ sub prepare {
 	unless ( $self->config ) {
 		$self->{config} = Config::Tiny->read( $self->image_conf );
 	}
-	unless ( _INSTANCE($self->config, 'Config::Tiny') ) {
+	unless ( Params::Util::_INSTANCE($self->config, 'Config::Tiny') ) {
 		Carp::croak("Failed to load scheme.conf config file");
 	}
 
@@ -313,12 +314,12 @@ sub prepare {
 	unless ( $self->server_uri ) {
 		Carp::croak("Missing 'server_uri' param in image.conf");
 	}
-	unless ( _INSTANCE($self->server_uri, 'URI::http') ) {
+	unless ( Params::Util::_INSTANCE($self->server_uri, 'URI::http') ) {
 		Carp::croak("The 'server_uri' is not a HTTP(S) URI");
 	}
 	unless ( $NOSERVER ) {
-		my $response = LWP::UserAgent->new->request( GET $self->server_uri );
-		unless ( $response and $response->is_success ) {
+		my $response = HTTP::Tiny->new( timeout => 5 )->get( $self->server_uri );
+		unless ( $response and $response->{success} ) {
 			Carp::croak("Failed to contact SupportServer at $config->{server_uri}");
 		}
 	}
@@ -359,7 +360,7 @@ sub prepare {
 		Carp::croak("Unknown task.task value in image.conf");
 	}
 
-	$self;	
+	$self;
 }
 
 sub run {
@@ -397,15 +398,14 @@ sub report {
 sub report_task {
 	my $self    = shift;
 	my $task    = shift;
-	my $agent   = LWP::UserAgent->new;
-	my $request = $self->report_task_request( $task );
-	unless ( _INSTANCE($request, 'HTTP::Request') ) {
-		Carp::croak("Did not generate proper report HTTP::Request");
+	my $request = $self->report_task_request($task);
+	unless ( ref($request) eq 'ARRAY' ) {
+		die "Did not generate proper report request";
 	}
 	unless ( $NOSERVER ) {
-		my $response = $agent->request( $request );
-		unless ( $response and $response->is_success ) {
-			Carp::croak("Failed to send result report to server");
+		my $response = HTTP::Tiny->new( timeout => 5 )->request(@$request);
+		unless ( $response and $response->{success} ) {
+			die "Failed to send result report to server";
 		}
 	}
 
@@ -413,7 +413,8 @@ sub report_task {
 }
 
 sub report_task_request {
-	my ($self, $task) = @_;	
+	my $self = shift;
+	my $task = shift;
 	unless ( $task->result ) {
 		Carp::croak("No Result Report created to PUT");
 	}
@@ -426,15 +427,22 @@ sub report_task_request {
 	}
 
 	# Send the file
-	PUT $self->report_task_uri( $task ),
-		content_type   => 'application/xml',
-		content_length => length($xml),
-		content        => $xml;
+	return [
+		'PUT' => $self->report_task_uri($task),
+		{
+			headers => {
+				content_type => 'application/xml',
+				content_length => length($xml),
+			},
+			content => $xml,
+		},
+	];
 }
 
 # The location to put to
 sub report_task_uri {
-	my ($self, $task) = @_;
+	my $self = shift;
+	my $task = shift;
 	my $uri  = $self->server_uri;
 	my $job  = $task->job_id;
 	my $path = File::Spec::Unix->catfile( $uri->path || '/', $job );
@@ -505,5 +513,3 @@ The full text of the license can be found in the
 LICENSE file included with this module.
 
 =cut
-
-1;
